@@ -39,7 +39,7 @@ class UsfmTextBase(ScriptureText):
         sentence_start = True
         prev_token: Optional[UsfmToken] = None
         prev_verse_ref = VerseRef()
-
+        is_verse_para = False
         for token in self._parser.parse(usfm):
             if token.type == UsfmTokenType.CHAPTER:
                 if chapter is not None and verse is not None:
@@ -76,15 +76,9 @@ class UsfmTextBase(ScriptureText):
                         verse = token.text
                 else:
                     verse = token.text
+                is_verse_para = True
             elif token.type == UsfmTokenType.PARAGRAPH:
-                if chapter is not None and verse is not None and not _is_verse_para(token):
-                    for seg in self._create_text_segments(
-                        include_text, prev_verse_ref, chapter, verse, text, sentence_start
-                    ):
-                        yield seg
-                    sentence_start = True
-                    text = ""
-                    verse = None
+                is_verse_para = _is_verse_para(token)
             elif token.type == UsfmTokenType.NOTE:
                 cur_embed_marker = token.marker
                 if chapter is not None and verse is not None and self._include_markers:
@@ -101,7 +95,7 @@ class UsfmTextBase(ScriptureText):
                     cur_embed_marker = None
                 if in_wordlist_marker and token.marker.marker == "w*":
                     in_wordlist_marker = False
-                if chapter is not None and verse is not None and self._include_markers:
+                if is_verse_para and chapter is not None and verse is not None and self._include_markers:
                     text += str(token)
             elif token.type == UsfmTokenType.CHARACTER:
                 assert token.marker is not None
@@ -109,7 +103,7 @@ class UsfmTextBase(ScriptureText):
                     cur_embed_marker = token.marker
                 elif token.marker.marker == "w":
                     in_wordlist_marker = True
-                if chapter is not None and verse is not None and self._include_markers:
+                if is_verse_para and chapter is not None and verse is not None and self._include_markers:
                     if (
                         prev_token is not None
                         and prev_token.type == UsfmTokenType.PARAGRAPH
@@ -118,7 +112,13 @@ class UsfmTextBase(ScriptureText):
                         text += str(prev_token) + " "
                     text += str(token) + " "
             elif token.type == UsfmTokenType.TEXT:
-                if chapter is not None and verse is not None and token.text is not None and token.text != "":
+                if (
+                    is_verse_para
+                    and chapter is not None
+                    and verse is not None
+                    and token.text is not None
+                    and token.text != ""
+                ):
                     if self._include_markers:
                         if (
                             prev_token is not None
@@ -150,12 +150,12 @@ class UsfmTextBase(ScriptureText):
 
     def _read_usfm(self) -> str:
         with self._create_stream_container() as stream_container, TextIOWrapper(
-            stream_container.open_stream(), encoding=self._encoding
+            stream_container.open_stream(), encoding=self._encoding, errors="replace"
         ) as reader:
             return reader.read()
 
 
-_NONVERSE_PARA_STYLES = {"ms", "mr", "s", "sr", "r", "d", "sp", "rem", "restore"}
+_NONVERSE_PARA_STYLES = {"ms", "mr", "s", "sr", "r", "d", "sp", "rem", "restore", "cl", "cp"}
 
 
 def _is_numbered_style(style_prefix: str, style: str) -> bool:
