@@ -7,16 +7,24 @@ from .thot_fast_align_word_alignment_model import ThotFastAlignWordAlignmentMode
 from .thot_hmm_word_alignment_model import ThotHmmWordAlignmentModel
 from .thot_ibm1_word_alignment_model import ThotIbm1WordAlignmentModel
 from .thot_ibm2_word_alignment_model import ThotIbm2WordAlignmentModel
+from .thot_ibm3_word_alignment_model import ThotIbm3WordAlignmentModel
+from .thot_ibm4_word_alignment_model import ThotIbm4WordAlignmentModel
+from .thot_symmetrized_word_alignment_model import ThotSymmetrizedWordAlignmentModel
 from .thot_word_alignment_model import ThotWordAlignmentModel
 from .thot_word_alignment_model_trainer import ThotWordAlignmentModelTrainer
 from .thot_word_alignment_model_type import ThotWordAlignmentModelType
+from .thot_word_alignment_parameters import ThotWordAlignmentParameters
 
 __all__ = [
     "ThotFastAlignWordAlignmentModel",
     "ThotHmmWordAlignmentModel",
     "ThotIbm1WordAlignmentModel",
     "ThotIbm2WordAlignmentModel",
+    "ThotIbm3WordAlignmentModel",
+    "ThotIbm4WordAlignmentModel",
+    "ThotSymmetrizedWordAlignmentModel",
     "ThotWordAlignmentModel",
+    "ThotWordAlignmentParameters",
     "ThotWordAlignmentModelTrainer",
     "ThotWordAlignmentModelType",
 ]
